#
# spec file for package uthash
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uthash
Version:        2.3.0
Release:        1.12
Summary:        Inline hash table for C structures
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/troydhanson/uthash
Source:         https://github.com/troydhanson/uthash/archive/v%{version}/%{name}-%{version}.tar.gz
Patch1:         uthash-proceed_with_tests_without_prompt.patch
Patch2:         uthash-optflags.patch
BuildRequires:  pkgconfig
BuildArch:      noarch

%description
uthash implements a hash table for C structures. It requires adding
a UT_hash_handle-typed member to your existing structure definition.

%package devel
Summary:        Development headers for uthash
Group:          Development/Libraries/C and C++
Obsoletes:      uthash <= 1.9.9

%description devel
This package provides development headers for uthash, a hash table
implementation for C structures.

%prep
%autosetup -p1

%build

%install
b=%{buildroot}
mkdir -p "$b/%{_includedir}"
cp -a src/*.h "$b/%{_includedir}/"

%check
pushd tests
OPTFLAGS="%{optflags}" \
#./all_funcs
popd

%files devel
%{_includedir}/*.h
%license LICENSE
%doc README.md

%changelog
* Fri Apr  2 2021 Wang Jun <jgwang@suse.com>
- udpate to 2.3.0:
  * remove HASH_FCN; the HASH_FUNCTION and HASH_KEYCMP macros
    now behave similarly
  * remove uthash_memcmp (deprecated in v2.1.0) in favor of
    HASH_KEYCMP
  * silence -Wswitch-default warnings (thanks, Olaf Bergmann!)
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- udpate to 2.2.0:
  * add HASH_NO_STDINT for platforms without C99 <stdint.h>
  * silence many -Wcast-qual warnings (thanks, Olaf Bergmann!)
  * skip hash computation when finding in an empty hash (thanks, Huansong Fu!)
  * rename oom to utarray_oom, in utarray.h (thanks, Hong Xu!)
  * rename oom to utstring_oom, in utstring.h (thanks, Hong Xu!)
  * remove MurmurHash/HASH_MUR
* Thu Oct 17 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.1.0
  * The library moved to become a fully header-only library. There
    is no more static archive. (And, for openSUSE, no more shared
    library.)
- Drop libut-shared.patch (fails to apply, usecase is gone)
- Switch to noarch as there are only headers and doc now.
* Tue Jan 24 2017 jengelh@inai.de
- Rename soname to sover to reflect use of the variable
- Update description to point out the implementation (and
  therefore, restrictions). Update RPM group.
* Sun Jul 10 2016 i@marguerite.su
- update version 2.0.1
  * add libut library
  * fix build for GCC 6
- upstream fixed boo#985142
- add patch libut-shared.patch
  * build shared version of libut
- split new subpackage -devel and libut2
* Fri Jul  1 2016 crrodriguez@opensuse.org
- test suite is defective, at least with gcc 6 on x86. skip
  for now.
* Thu Mar  5 2015 mpluskal@suse.com
- Update source url
- Update to 1.9.9
  * made HASH_ADD_STR compatible with char* or char[]
  * fixed header inclusion of sys/types.h for ssize_t
  * added LL_COUNT/DL_COUNT/CDL_COUNT
  * added LRU cache example in tests/lru_cache
  * fix LL_DELETE2 for VS2008
  * fix missing argument in HASH_REPLACE_STR
  * bump version number in source files to match docs
  * add HASH_OVERHEAD macro to get overhead size for hash table
- Changes for 1.9.8
  * HASH_REPLACE now in uthash
  * fixed clang warnings
  * fixed utarray_insert when inserting past array end
  * you can now find uthash on GitHub
  * there’s a uthash Google Group
  * uthash has been downloaded 29,000+ times since 2006 on
    SourceForge
- Changes for 1.9.7
  * utstring now supports substring search using utstring_find
  * utlist now supports element prepend and replace
  * utlist element prev/next fields can now have any names
  * uthash cast quiets a clang warning
  * uthash userguide example shows how to check key uniqueness
  * uthash HASH_MUR compiles under MSVC++ 10 in C mode
  * utstring_printf now supports format checking
* Tue Feb 28 2012 pascal.bleser@opensuse.org
- initial version (1.9.5)
